#!/bin/bash

set -e

# add tools
pwd=`pwd`
PATH=$pwd:$PATH
for d in ttsdk/{ADDTABLE,FLINT,SBIT,TTC,TTFDUMP/TTFDUMP.NT} ttfmod ttfname3; do
    PATH=$pwd/tools/$d:$PATH
done
export PATH

rm -rfv tmp
mkdir tmp
cd tmp

echo "* Copying TTF."
cp -v $pwd/ipafont/IPAfont00203/*.ttf .

ttfs="ipag ipagp ipagui ipam ipamp"

echo "* Check EBDT."
for f in $ttfs; do
    SBIT32 -i $f.ttf | awk '/ppem:/ {print $2}'
done | sort | uniq > EBDT.list

for dot in `cat EBDT.list`; do
    echo "PPEM $dot" > $dot.size
done

echo "* Remove EBDT."
for f in $ttfs; do
    echo "  - $f.ttf -> ${f}NB.ttf"
    cp $f.ttf tmp_s.ttf
    for dot in `cat EBDT.list`; do
	SBIT32 -d tmp_s.ttf $dot.size tmp_d.ttf
	mv tmp_d.ttf tmp_s.ttf
    done
    mv tmp_s.ttf ${f}NB.ttf
done

echo "* Modify GASP."
for f in *NB.ttf; do
    ttfmod $f
done
echo ""

echo "* Modify font name."
for f in *NB.ttf; do
    n=${f/.ttf/}
    ttfname3 $f &
    until [ -f $n.xml ]; do
	sleep 1
    done
    chfn.pl $n.xml
    ttfname3 $f ${n}_mod.xml -o ${n}_mod.ttf &
    until [ -f ${n}_mod.ttf ]; do
	sleep 1
    done
    mv -v ${n}_mod.ttf $f
done
